Welcome to `ir-metrics`
=======================

`ir-metrics` is a python package that contains definition of the most common information retrieval metrics. The main goal of this project is to provide a common interface for various IR tasks.


Documentation
-------------

This part of the documentation shows the intended ways to use the package.

.. include:: basic.rst
.. include:: relevance.rst
.. include:: pandas.rst
.. include:: pyspark.rst


API Reference
-------------

Information about specific functions.

.. toctree::
   :maxdepth: 2

   api
